%% Runge-Kutta Integration to Simulate Incoming Comet in Sun and Jupiter gravitaional field


%mass of objects and constant

global ms mp ma G

ms = 10^7;  %mass of sun
mp = 10^4;  %mass of planet 
ma = (10*rand()+0.1); % random mass of comet between 0.1 and 10.1
G = 1; % gravitational constant



%initial positions

rs = [0,0]'; %position of sun
rp = [20,0]'; %position of planet

rcm = (mp*rp+ms*rs)/(mp+ms); %center of mass

rs = rs-rcm; %exact position of sun
rp = rp-rcm; %exact position of planet
ra = [30*(2*rand()-1),25*rand()+25]'; %initial position of comet



%initial velocity

mu = ms*mp/(ms+mp); %effective mass

R =norm(abs(rs-rp),2); %distance between sun and planet

w = sqrt(G*ms*mp/R^3/mu); %angular velocity

vs = [[0,-1];[1,0]]*w*rs; %velocity of sun
vp = [[0,-1];[1,0]]*w*rp; %velocity of planet
va = [200*rand-10,-1000*rand()]; %velocity of comet



%initial y

y = [rs(1),rs(2),vs(1),vs(2),rp(1),rp(2),vp(1),vp(2),ra(1),ra(2),va(1),va(2)];



%time step

dt = T/4000;



%iteration

f = 0; % # of images

z = 0; % # of iterations

for i = 1:10000
    
    f1 = kepler_ode_gen(y); % it is not dependent on time
    f2 = kepler_ode_gen(y+dt/2.*f1);
    f3 = kepler_ode_gen(y+dt/2.*f2);
    f4 = kepler_ode_gen(y+dt.*f3);
   
    y = y+dt/6.*(f1+2.*f2+2.*f3+f4); %Runge-Kutta Method

    z = z+1; %number of iteration
    
    disp(z)
    
    
    if mod(z,100) == 0 %save images for every 100 interations
       
    f = f+1;    
    
    plot(y(1),y(2),'r.','MarkerSize',30)
    hold on
    plot(y(5),y(6),'b.','MarkerSize',20)
    plot(y(9),y(10),'g.','MarkerSize',10)
    title('Incoming Comet')
    axis([-100 100 -100 100])
    whitebg(gcf,'k')
    set(gcf, 'InvertHardCopy', 'off');
    saveas(gcf, ['orbit_', sprintf('%03d',f),'.png'])
    pause(0.001)
    disp(f)
    hold off
    
    end
     
end


